pub struct AssembledEntityContext {
pub name: String,
pub relevance: String,
pub via_entity: String,
pub via_relation: String,
pub relationships: Vec<EntityRelation>,
}Fields
name: Stringrelevance: String“direct_mention” or “graph_neighbor”
via_entity: StringFor graph_neighbor, the entity connected through
via_relation: StringFor graph_neighbor, the relation type
relationships: Vec<EntityRelation>Trait Implementations
Sourceimpl Clone for AssembledEntityContext
impl Clone for AssembledEntityContext
Sourcefn clone(&self) -> AssembledEntityContext
fn clone(&self) -> AssembledEntityContext
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AssembledEntityContext
impl Debug for AssembledEntityContext
Sourceimpl Default for AssembledEntityContext
impl Default for AssembledEntityContext
Sourceimpl Message for AssembledEntityContext
impl Message for AssembledEntityContext
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for AssembledEntityContext
impl PartialEq for AssembledEntityContext
Sourcefn eq(&self, other: &AssembledEntityContext) -> bool
fn eq(&self, other: &AssembledEntityContext) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AssembledEntityContext